fn mounts_for_device(device_name: &str) -> Vec<DiskMountMetrics>Expand description
Read /proc/mounts and return filesystem space for all mount points whose
source device path starts with /dev/<device_name> (covers partitions too).
fn mounts_for_device(device_name: &str) -> Vec<DiskMountMetrics>Read /proc/mounts and return filesystem space for all mount points whose
source device path starts with /dev/<device_name> (covers partitions too).